c        
      common /BPgene/ media, Eeme, Egme
      common /BPgeneC/ force
      record /epmedia/  media
      real*8 Eeme, Egme
      character(8):: force

